@@ -1,9 +1,10 @@
+# frozen_string_literal: true
+
 require "guard/commands/pause"
 
 RSpec.describe Guard::Commands::Pause do
   class FakePry < Pry::Command
-    def self.output
-    end
+    def self.output; end
   end
 
   before do
