@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require "guard/config"
 
 unless Guard::Config.new.strict?
@@ -22,27 +24,27 @@ unless Guard::Config.new.strict?
       allow(state).to receive(:session).and_return(session)
       allow(Guard).to receive(:state).and_return(state)
 
-      allow(evaluator).to receive(:guardfile_path).
-        and_return(File.expand_path("foo"))
+      allow(evaluator).to receive(:guardfile_path)
+        .and_return(File.expand_path("foo"))
 
-      allow(::Guard::Guardfile::Evaluator).to receive(:new).with(options).
-        and_return(evaluator)
+      allow(::Guard::Guardfile::Evaluator).to receive(:new).with(options)
+                                                           .and_return(evaluator)
 
       allow(Guard::UI).to receive(:deprecation)
     end
 
     describe ".match_guardfile?" do
       it "displays a deprecation warning to the user" do
-        expect(Guard::UI).to receive(:deprecation).
-          with(Guard::Deprecated::Watcher::ClassMethods::MATCH_GUARDFILE)
+        expect(Guard::UI).to receive(:deprecation)
+          .with(Guard::Deprecated::Watcher::ClassMethods::MATCH_GUARDFILE)
 
-        files = %w(foo bar)
+        files = %w[foo bar]
         subject.match_guardfile?(files)
       end
 
       it "matches against current guardfile" do
-        expect(subject.match_guardfile?(%w(foo bar))).to be(true)
-        expect(subject.match_guardfile?(%w(bar))).to be(false)
+        expect(subject.match_guardfile?(%w[foo bar])).to be(true)
+        expect(subject.match_guardfile?(%w[bar])).to be(false)
       end
     end
   end
