@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require "guard/watcher/pattern/deprecated_regexp"
 
 RSpec.describe Guard::Watcher::Pattern::DeprecatedRegexp do
@@ -15,7 +17,7 @@ RSpec.describe Guard::Watcher::Pattern::DeprecatedRegexp do
       "^foo.rb" => /^foo.rb/,
       "foo.rb$" => /foo.rb$/,
       'foo\.rb' => /foo\.rb/,
-      ".*rb" => /.*rb/,
+      ".*rb" => /.*rb/
     }.each do |pattern, regexp|
       context "with #{pattern}" do
         it "creates a Matcher with #{regexp}" do
